diff Core/HttpServer/HttpOutput.h @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 9be852ad33d2
children c996319e90bc
line wrap: on
line diff
--- a/Core/HttpServer/HttpOutput.h	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/HttpServer/HttpOutput.h	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,12 +25,12 @@
 #include "../Enumerations.h"
 #include "../FileStorage.h"
 
-namespace Palantir
+namespace Palanthir
 {
   class HttpOutput
   {
   private:
-    void SendHeaderInternal(Palantir_HttpStatus status);
+    void SendHeaderInternal(Palanthir_HttpStatus status);
 
     void SendOkHeader(const char* contentType,
                       bool hasContentLength,
@@ -56,7 +56,7 @@
 
     void SendMethodNotAllowedError(const std::string& allowed);
 
-    void SendHeader(Palantir_HttpStatus status);
+    void SendHeader(Palanthir_HttpStatus status);
 
 
     // Higher-level constructs to send entire files or buffers -------------------
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium